pub trait Executor:
Send
+ Sync
+ 'static {
// Required method
fn execute(&self, r: Run);
}👎Deprecated
A trait representing requests to poll futures.
This trait is an argument to the Spawn::execute which is used to run a
future to completion. An executor will receive requests to run a future and
an executor is responsible for ensuring that happens in a timely fashion.
Note that this trait is likely to be deprecated and/or renamed to avoid
clashing with the future::Executor trait. If you’ve got a use case for
this or would like to comment on the name please let us know!
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".